=================
Todos
=================

parsing TRIM.in
===============

Is this mandatory or not?

Help Message
============

permission from original tin.exe is required

Material Database
=================

- spec for tin.exe (and permission for use) is required

- user defined layer data will be helpful.
  UI to access compound.dat given by SRIM is implemented at version 0.1.0
